#
# spec file for package python-pytest-check
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-check
Version:        2.4.1
Release:        1.1
Summary:        A pytest plugin that allows multiple failures per test
License:        MIT
URL:            https://github.com/okken/pytest-check
Source:         https://files.pythonhosted.org/packages/source/p/pytest-check/pytest_check-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module flit-core >= 2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 6}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pytest >= 6
BuildArch:      noarch
%python_subpackages

%description
A pytest plugin that allows multiple failures per test. A rewrite of pytest-expect

%prep
%setup -q -n pytest_check-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc README.md
%{python_sitelib}/pytest_check
%{python_sitelib}/pytest_check-%{version}*-info

%changelog
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 2.4.1:
  * Added `is_nan()` and `is_not_nan()`
  * Drop Python 3.7
  * Add testing for Python 3.12
  * Add tox-uv to tox.ini and main.yml
* Thu Feb  1 2024 Dirk Müller <dmueller@suse.com>
- update to 2.3.1:
  * Documentation Update, README.md
  * Turn help function list into a table with param lists
  * Show an alternative method of creating a helper function
    using `check.fail()`
  * `fail(msg)` - indicate test failure, but don't stop testing
  * Summaries from 2.2.3 are cool, but don't work with xdist
* Tue Jan  9 2024 Dirk Müller <dmueller@suse.com>
- update to 2.2.4:
  * fix 153
  * Summaries from 2.2.3 are cool, but don't work for pytest <
    7.3; Remove them for earlier pytest
  * Add tox test run for pytest 7.0.0
  * Change dependencies to require 7.0.0 pytest
* Fri Jan  5 2024 Dirk Müller <dmueller@suse.com>
- update to 2.2.3:
  * Check failure info now shows up in summaries.
* Mon Oct  2 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.2:
  * fixed Issue #7
* Thu Sep  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.1:
  * Increase Python range to include 3.7.0. Thanks EliahKagan
* Mon Jul 24 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.0:
  * pseudo traceback additions
    `-l` or `--showlocals` shows locals
    `__tracebackhide__ = True` is honored.
  * Fix 127 IndexError when running a check in a thread
  * include tests an examples in sdist -  pr 121
  * README.md - clean up documentation for `--check-max-tb`.
  * Minor internal cleanup - removed some debug code.
  * `check.call_on_fail(func)` - ***Experimental***
  * Name changed from `check.set_failure_callback(func)`.
  * This "func" function will be called for each failed check,
    and needs to accept a string parameter.
  * With the following change, the default is now pretty darn
    fast, and most people will not need to modify any settings to
    get most of the speed improvements.
  * `--check-max-tb=<int>` - sets the max number of pseudo-
    traceback reports per test function.
  * `check.set_no_tb` and `--set-no-tb` will be removed in a
    future release. (probably soon)
  * Since `--check-max-tb` is more useful, the default for
    `--check-max-tb` is 1, which is already pretty fast.
  * And `--check-max-tb=0` has the same effect as `--check-no-
    tb`.
  * Most changes are related to speedup improvements.
  * use `--check-no-tb --check-max-report=10` to get super zippy.
  * `check.between()` added just for fun
  * Rewrote `check.equal()` and other helper functions to not use
    assert.
  * `--check-no-tb` - turn off tracebacks
  * `--check-max-report` - limit reported failures per test
    function
  * `--check-max-fail` - limit failures per test function
  * `check.set_no_tb()` - turn off tracebacks for one test
    function
  * `check.set_max_report()` - limit reports for one test
    function
  * `check.set_max_fail()` - limit failures for one test function
  * `check.between(b, a, c)` - check that a < b < c
  * Add `any_failures()`.
  * While using the `check` fixture, allow `check.check` as a
    context manager. this is unnecessary, the `check` fixture
    now works as a context manager.
* Thu Jul 14 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for v1.0.5
- Required to test pyhton-sphobjinv
